From 9a68a5ea4d98bbd99d595e3e6408e1d7e1399a2d Mon Sep 17 00:00:00 2001
From: mrfenyx <mircea.marin@gmail.com>
Date: Wed, 29 Sep 2021 19:50:19 +0200
Subject: [PATCH] Added dictionary with possible sender events based on
 official Selve documentation; Added function for interpreting the
 "selve.GW.event.sender" method Call.

---
 lib/SelveUSBGateway.js | 32 ++++++++++++++++++++++++++++++++
 1 file changed, 32 insertions(+)

diff --git a/lib/SelveUSBGateway.js b/lib/SelveUSBGateway.js
index f3c0769..9b9ce0f 100644
--- a/lib/SelveUSBGateway.js
+++ b/lib/SelveUSBGateway.js
@@ -48,6 +48,23 @@ const RECONNECT_TIMEOUT_DURATION = 10000; //ms
 const NUM_OF_RETRIES_AFTER_FAULT_AND_TIMEOUT = 3;
 const DELAY_BETWEEN_MULTIPLE_MESSAGES = 10; //ms
 
+const SENDER_EVENTS = {
+	0 : "no events are available. (Status after startup)",
+	1 : "the Drive Up Key was pressed",
+	2 : "the Drive Down Key was pressed",
+	3 : "the Stop Key was pressed",
+	4 : "the Intermediate Position 1 Key was pressed (Shading)",
+	5 : "the Intermediate Position 2 Key was pressed (Ventilation)",
+	6 : "the Intermediate Position 1 was saved",
+	7 : "the Intermediate Position 2 was saved",
+	8 : "the operation mode switch was set to AUTO",
+	9 : "the operation mode switch was set to MAN",
+	10: "the name of the sender was changed",
+	11: "a key was released (event generated only during teaching-in process)",
+	12: "a gateway was selected",
+	13: "the connection to a gateway was deleted and is not available for further events anymore"
+};
+
 class SelveUSBGateway {
 
 
@@ -540,6 +557,21 @@ class SelveUSBGateway {
 					data["methodCall"]["array"][0]["int"][11]
 				);
 			}
+			else if (data["methodCall"]["methodName"] == "selve.GW.event.sender")
+			{
+				const senderID = data["methodCall"]["array"][0]["int"][0];
+				const senderName = data["methodCall"]["array"][0]["string"][0];
+				const event = data["methodCall"]["array"][0]["int"][1];
+				
+				if (event >= 0 && event <= 13) 
+				{
+					this.adapter.log.info("Sender " + senderName + " with ID: " + senderID + ", reports " + SENDER_EVENTS[event]);
+				}
+				else 
+				{
+					this.adapter.log.warn("Sender " + senderName + " with ID: " + senderID + ", reports an unkown event (" + event + "): " + JSON.stringify(data));
+				}
+			}
 			else
 			{
 				this.adapter.log.warn("Not implemented method call message from gateway: " + JSON.stringify(data));
-- 
2.33.0.windows.2

